Page 86 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 86

Home

    France, and the Bank of Germany.

    To accomplish their goal of establishing a central
    bank, the Money Trust used a proven method of
    revolution, that of creating a crisis and then offering a
    solution, the solution being what the perpetrators wanted
    in the first place.

    mown: eann *.

    In this case, the crisis was the Bank Panic of 1907. It
    was created by J. P. Morgan spreading the rumor that the
    Trust Company of America (a private bank) was
    insolvent. This resulted in snowballing bank runs. The
    Money Trust then came forward with a solution to
    prevent bank runs, a central bank to control all banking
    in the United States.

    Plans for a central bank were formalized, in 1910, in
    a secret meeting at J. P. Morgan's hunting club on Jekyll
    Island, off the coast of Georgia. At this meeting, along
    with representatives of the Money Trust, was Senator
    Nelson Aldrich, a relative of the Rockefellers. Aldrich
    became the chief proponent of legislation in Congress to
    create a central bank. In December of 1913, Congress
    passed legislation creating the Federal Reserve. The
    United States had a central bank.

    conspirators to get the American people to accept a
    central bank. This method is always to promise just the
    opposite of what you intend to do. The Federal Reserve

    was sold to Congress as a way to stabilize the economy
    and prevent future bank runs. It did just the opposite. It

    81

    Building Modern Babylon

    Rothschilds owned the Bank of England, the Bank of

    Another time worn method was used by the